@@ -1,6 +1,5 @@
-#!/bin/bash
+#!/usr/bin/bash
 # -*- shell-script -*-
-
 test_columnized()
 {
     do_one() {
@@ -18,13 +17,13 @@ test_columnized()
 	fi
 	typeset size=${#columnized[@]}
 # 	typeset -i i
-# 	for ((i=0; i<${#columnized[@]}; i++)) ; do 
+# 	for ((i=0; i<${#columnized[@]}; i++)) ; do
 # 	    print "  ${columnized[i]}"
 # 	done
 	assertEquals "$cols" "$size"
 	assertEquals "$last_line" "${columnized[$size-1]}"
     }
-    do_one 1 '<empty>' '' 
+    do_one 1 '<empty>' ''
     do_one 1 'a,2,c' 'a 2 c' 10 ','
     do_one 4 'for    8  ' \
 ' 1   two three
@@ -39,17 +38,15 @@ test_columnized()
 
 }
 
-if [ '/src/external-vcs/bashdb-3.1' = '' ] ; then
+if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-vcs/bashdb-3.1
-# Make sure @abs_top_srcr@ has a trailing slash
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+# Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
-
+. ${abs_top_srcdir}test/unit/helper.sh
 . $abs_top_srcdir/lib/columnize.sh
 
-# load shunit2
-srcdir=.
-srcdir=${srcdir}/
-. ${srcdir}/shunit2
+set -- # reset $# so shunit2 doesn't get confused.
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
